==> bacula-doc_5.0.1.orig.tar.bz2: bacula-docs-5.0.1/home-page/fr/pages/home.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
   <td class="contentTopic">
      Bacula&reg; - La solution de sauvegarde par le r&eacute;seau
   </td>
</tr>
<tr>
  <td class="content">
     <b>Bacula</b> est un ensemble de programmes qui vous permet de g&eacute;rer vos
     sauvegardes, restaurations ou v&eacute;rifications de donn&eacute;es d'un ordinateur
     sur un r&eacute;seau h&eacute;t&eacute;rog&egrave;ne.
     <br>

     <br>
     En termes techniques, il s'agit d'un <b>programme de sauvegarde
     client/serveur</b>. Bacula est relativement facile d'utilisation et efficace, tout en offant
     de nombreuses fonctions avanc&eacute;es de gestion de stockage qui facilitent la
     recherche et la restauration de fichiers perdus ou endommag&eacute;s
     <br> 


     <br>


     <br> Selon les statistiques de Source Forge (rank et downloads), Bacula est
     de loin le plus populaire des logiciels Open Source de qualit&eacute; entreprise.
     <br>
     <br>

<table width="759" border="0" cellspacing="2" cellpadding="0">
   <tr>
    <td width="25"></td>
    <td><font size="5" color="#739ab9"> <strong>Bacula.org et Bacula Systems: 
          Comment trouver ce qui vous convient.</strong></font></td>
   </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
</table>

<p></p>
<table width="644" border="0" cellspacing="0" cellpadding="0" height="224">
 <tr height="215">
  <td align="center" valign="middle" width="331" height="215">
   <table width="237" border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td>
      <table width="158" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
       <tr>
        <td valign="top">
         <table class="cellcolor" width="276" border="0" cellspacing="0" cellpadding="0" height="137">
          <tr height="137">
           <td width="5" height="137"></td>
           <td width="210" height="137">
            <h4>Bacula.org est le point d'origine du projet Bacula, pour les d&eacute;veloppeurs et les contributeurs.
            Vous pouvez trouver la derni&egrave;re version de Bacula ainsi que toute la documentation ici. </h4>
           </td>
          </tr>
         </table>
        </td>
       </tr>
      </table>
     </td>
    </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
    <tr height="68">
     <td height="68">
      <p>18 Octobre 2009: <strong>Bacula 3.0.3</strong> a &eacute;t&eacute; relach&eacute;.</p>
      <p></p>
      <p>Voir: <a href="http://www.bacula.org/en/?page=news">News</a></p>
     </td>
    </tr>
   </table>
  </td>
  <td rowspan="2" width="25" height="229">
   <table class="cellcolor" width="3" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="320">
    <tr height="60">
     <td height="60"></td>
    </tr>
   </table>
  </td>
  <td align="center" valign="middle" width="210" height="215">
   <table width="288" border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td>
      <table width="276" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
       <tr>
        <td valign="top">
         <table class="cellcolor" width="264" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
          <tr height="137">
           <td width="5" height="137"></td>
           <td width="271" height="137">

            <h4><a href="http://www.baculasystems.com">Bacula Systems</a> vous
            apporte un support, des services et des formations professionnels
            pour les entreprises utilisant Bacula. Le site internet de Bacula Systems
            se trouve sur <a href="http://www.baculasystems.com">www.baculasystems.com</a></h4>

           </td>
          </tr>
         </table>
        </td>
       </tr>
      </table>
     </td>
    </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
    <tr height="68">
     <td height="68">
      <p>7 juillet 2009: <strong><a href="http://www.baculasystems.com/eng/Products/Enterprise-Edition">
                     Bacula Enterprise Edition 2.6</a></strong> has been released.</p>
      <p>10 juin 2009: <strong>Foundation Training Course: <a href="http://www.baculasystems.com/eng/About-us/Recent-news/Foundation-Course-Dates-Announced">dates announced</a><p>
      <p>Voir: <a href="http://www.baculasystems.com/eng/About-us/Recent-news">Bacula Systems News</a>
<!--
, 
          or <a href="http://www.baculasystems.com/eng/Products/Enterprise-Edition">
          Bacula Enterprise Edition main page</a></p>     
-->
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr align="center" height="14">
  <td width="331" height="14">
   <table class="cellcolor" width="209" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="3">
    <tr align="center" height="3">
     <td align="right" width="275" height="3"></td>
    </tr>
   </table>
  </td>
  <td width="210" height="14">
   <table class="cellcolor" width="209" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="3">
    <tr height="3">
     <td width="209" height="3"></td>
    </tr>
   </table>
  </td>
 </tr>
</table>
<p></p>

     <br>
     La plupart du code source de <b>Bacula</b> a &eacute;t&eacute; publi&eacute;e sous une version
     quelque peu modifi&eacute;e de la license <b>GPL</b> version 2. Pour toute
     information compl&eacute;mentaire sur la license, merci de suivre le lien du
     menu.
     <br>

     <br>Le lien Documentation pointe sur une page qui permet d'acc&eacute;der &aacute;
     toutes les documentations de Bacula disponibles (HTML, PDF et TGZ) que ce
     soit pour la derni&egrave;re version officielle ou bien pour le code
     actuellement en cours de d&eacute;veloppement dans le GIT SourceForge.
     La version de d&eacute;veloppement du manuel contient plus de documentation, mais
     aussi la documentation des derni&egrave;res fonctionnalit&eacute;s qui ne sont pas
     encore incluses dans la derni&egrave;re version publi&eacute;e.
     <br>
     Le guide du d&eacute;veloppeur pr&eacute;sente des informations importantes pour les
     utilisateurs qui veulent contribuer au projet Bacula.
     <br>
     
     <br>Bacula est h&eacute;berg&eacute; sur <a
     href="http://sourceforge.net/projects/bacula">
     http://sourceforge.net/projects/bacula </a> d'o&ugrave; vous pouvez t&eacute;l&eacute;charger
     le logiciel.
     <br>
     
     <br>Vous pouvez &eacute;galement utiliser les liens du menu pour acc&eacute;der
     directement &aacute; la version courante ou bien &aacute; toutes les versions d&eacute;j&aacute;
     publi&eacute;es sur SourceForge.

  </td>
</tr>
</table>

<? require_once("inc/footer.php"); ?>

==> bacula-doc_5.0.2.orig.tar.bz2: bacula-docs-5.0.2/home-page/fr/pages/home.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
   <td class="contentTopic">
      Bacula&reg; - La solution de sauvegarde par le r&eacute;seau
   </td>
</tr>
<tr>
  <td class="content">
     <b>Bacula</b> est un ensemble de programmes qui vous permet de g&eacute;rer vos
     sauvegardes, restaurations ou v&eacute;rifications de donn&eacute;es d'un ordinateur
     sur un r&eacute;seau h&eacute;t&eacute;rog&egrave;ne.
     <br>

     <br>
     En termes techniques, il s'agit d'un <b>programme de sauvegarde
     client/serveur</b>. Bacula est relativement facile d'utilisation et efficace, tout en offant
     de nombreuses fonctions avanc&eacute;es de gestion de stockage qui facilitent la
     recherche et la restauration de fichiers perdus ou endommag&eacute;s
     <br> 


     <br>


     <br> Selon les statistiques de Source Forge (rank et downloads), Bacula est
     de loin le plus populaire des logiciels Open Source de qualit&eacute; entreprise.
     <br>
     <br>

<table width="759" border="0" cellspacing="2" cellpadding="0">
   <tr>
    <td width="25"></td>
    <td><font size="5" color="#739ab9"> <strong>Bacula.org et Bacula Systems: 
          Comment trouver ce qui vous convient.</strong></font></td>
   </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
</table>

<p></p>
<table width="644" border="0" cellspacing="0" cellpadding="0" height="224">
 <tr height="215">
  <td align="center" valign="middle" width="331" height="215">
   <table width="237" border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td>
      <table width="158" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
       <tr>
        <td valign="top">
         <table class="cellcolor" width="276" border="0" cellspacing="0" cellpadding="0" height="137">
          <tr height="137">
           <td width="5" height="137"></td>
           <td width="210" height="137">
            <h4>Bacula.org est le point d'origine du projet Bacula, pour les d&eacute;veloppeurs et les contributeurs.
            Vous pouvez trouver la derni&egrave;re version de Bacula ainsi que toute la documentation ici. </h4>
           </td>
          </tr>
         </table>
        </td>
       </tr>
      </table>
     </td>
    </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
    <tr height="68">
     <td height="68">
      <p>25 F&eacute;vrier 2010: <strong>Bacula 5.0.1</strong> a &eacute;t&eacute; relach&eacute;.</p>
      <p></p>
      <p>Voir: <a href="http://www.bacula.org/en/?page=news">News</a></p>
     </td>
    </tr>
   </table>
  </td>
  <td rowspan="2" width="25" height="229">
   <table class="cellcolor" width="3" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="320">
    <tr height="60">
     <td height="60"></td>
    </tr>
   </table>
  </td>
  <td align="center" valign="middle" width="210" height="215">
   <table width="288" border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td>
      <table width="276" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
       <tr>
        <td valign="top">
         <table class="cellcolor" width="264" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9">
          <tr height="137">
           <td width="5" height="137"></td>
           <td width="271" height="137">

            <h4><a href="http://www.baculasystems.com">Bacula Systems</a> vous
            apporte un support, des services et des formations professionnels
            pour les entreprises utilisant Bacula. Le site internet de Bacula Systems
            se trouve sur <a href="http://www.baculasystems.com">www.baculasystems.com</a></h4>

           </td>
          </tr>
         </table>
        </td>
       </tr>
      </table>
     </td>
    </tr>
    <tr height="10">
     <td height="10"></td>
    </tr>
    <tr height="68">
     <td height="68">
      <p>7 juillet 2009: <strong><a href="http://www.baculasystems.com/eng/Products/Enterprise-Edition">
                     Bacula Enterprise Edition 2.6</a></strong> has been released.</p>
      <p>10 juin 2009: <strong>Foundation Training Course: <a href="http://www.baculasystems.com/eng/About-us/Recent-news/Foundation-Course-Dates-Announced">dates announced</a><p>
      <p>Voir: <a href="http://www.baculasystems.com/eng/About-us/Recent-news">Bacula Systems News</a>
<!--
, 
          or <a href="http://www.baculasystems.com/eng/Products/Enterprise-Edition">
          Bacula Enterprise Edition main page</a></p>     
-->
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr align="center" height="14">
  <td width="331" height="14">
   <table class="cellcolor" width="209" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="3">
    <tr align="center" height="3">
     <td align="right" width="275" height="3"></td>
    </tr>
   </table>
  </td>
  <td width="210" height="14">
   <table class="cellcolor" width="209" border="0" cellspacing="0" cellpadding="0" bgcolor="#739ab9" height="3">
    <tr height="3">
     <td width="209" height="3"></td>
    </tr>
   </table>
  </td>
 </tr>
</table>
<p></p>

     <br>
     La plupart du code source de <b>Bacula</b> a &eacute;t&eacute; publi&eacute;e sous une version
     quelque peu modifi&eacute;e de la license <b>GPL</b> version 2. Pour toute
     information compl&eacute;mentaire sur la license, merci de suivre le lien du
     menu.
     <br>

     <br>Le lien Documentation pointe sur une page qui permet d'acc&eacute;der &aacute;
     toutes les documentations de Bacula disponibles (HTML, PDF et TGZ) que ce
     soit pour la derni&egrave;re version officielle ou bien pour le code
     actuellement en cours de d&eacute;veloppement dans le GIT SourceForge.
     La version de d&eacute;veloppement du manuel contient plus de documentation, mais
     aussi la documentation des derni&egrave;res fonctionnalit&eacute;s qui ne sont pas
     encore incluses dans la derni&egrave;re version publi&eacute;e.
     <br>
     Le guide du d&eacute;veloppeur pr&eacute;sente des informations importantes pour les
     utilisateurs qui veulent contribuer au projet Bacula.
     <br>
     
     <br>Bacula est h&eacute;berg&eacute; sur <a
     href="http://sourceforge.net/projects/bacula">
     http://sourceforge.net/projects/bacula </a> d'o&ugrave; vous pouvez t&eacute;l&eacute;charger
     le logiciel.
     <br>
     
     <br>Vous pouvez &eacute;galement utiliser les liens du menu pour acc&eacute;der
     directement &aacute; la version courante ou bien &aacute; toutes les versions d&eacute;j&aacute;
     publi&eacute;es sur SourceForge.

  </td>
</tr>
</table>

<? require_once("inc/footer.php"); ?>
